@@ -87,7 +87,8 @@ ciplot <-
                  xat=NULL, xlim=NULL, xaxs="r", xlab=NULL,
                  yat=NULL, ylim=NULL, yaxs="r", ylab=NULL,
                  las=1, pch=21, bg="slateblue", ci_col="black",
-                 ci_lwd=2, ci_endseg=0.05, labels=NULL, main="", ...)
+                 ci_lwd=2, ci_endseg=0.05, labels=NULL, main="",
+                 mgp.x=NULL, mgp.y=NULL, mgp=NULL, ...)
 
         {
             n_group <- length(est)
@@ -110,7 +111,7 @@ ciplot <-
                          hlines=hlines, hlines.col=hlines.col, hlines.lwd=hlines.lwd,
                          xat=xat, xlim=xlim, xaxs=xaxs, xlab=xlab,
                          yat=yat, ylim=ylim, yaxs=yaxs, ylab=ylab, las=las, type="n",
-                         main=main)
+                         main=main, mgp=mgp, mgp.x=mgp.x, mgp.y=mgp.y, ...)
                 axis(side=1, at=vlines, labels, las=las, tick=FALSE, mgp=c(0,0.2,0))
 
                 segments(group, lo, group, hi, col=ci_col, lwd=ci_lwd)
@@ -135,7 +136,8 @@ ciplot <-
                          hlines=hlines, hlines.col=hlines.col, hlines.lwd=hlines.lwd,
                          xat=xat, xlim=xlim, xaxs=xaxs, xlab=xlab,
                          yat=yat, ylim=ylim, yaxs=yaxs, ylab=ylab,
-                         v_over_h=TRUE, las=las, type="n", ...)
+                         v_over_h=TRUE, las=las, type="n", main=main,
+                         mgp=mgp, mgp.x=mgp.x, mgp.y=mgp.y, ...)
                 axis(side=2, at=hlines, labels, las=las, tick=FALSE, mgp=c(0,0.3,0))
 
                 segments(lo, group, hi, group, col=ci_col, lwd=ci_lwd)
